<!-- warning: Please don't edit this file. It was automatically generated. -->

# winrt-Windows.Storage.BulkAccess

Windows Runtime (WinRT) APIs for for the `Windows.Storage.BulkAccess` namespace.

This package provides the `winrt.windows.storage.bulkaccess` module.
